package xyz.lychee.lagfixer;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.Map;
import org.bukkit.configuration.ConfigurationSection;
import org.bukkit.configuration.InvalidConfigurationException;
import org.bukkit.configuration.file.YamlConfiguration;
import xyz.lychee.lagfixer.libs.adventure.text.Component;
import xyz.lychee.lagfixer.libs.adventure.text.ComponentLike;
import xyz.lychee.lagfixer.libs.adventure.text.minimessage.MiniMessage;
import xyz.lychee.lagfixer.libs.adventure.text.minimessage.tag.resolver.TagResolver;
import xyz.lychee.lagfixer.libs.adventure.text.serializer.legacy.LegacyComponentSerializer;
import xyz.lychee.lagfixer.libs.annotations.Nullable;
import xyz.lychee.lagfixer.managers.ConfigManager;
import xyz.lychee.lagfixer.objects.AbstractModule;

public class Language {
   private static final YamlConfiguration yaml = new YamlConfiguration();
   private static final LegacyComponentSerializer serializer = LegacyComponentSerializer.builder().character('&').hexCharacter('#').hexColors().useUnusualXRepeatedCharacterHexFormat().build();
   private static final Map<String, String> mainValues = new HashMap();
   private final AbstractModule module;
   private final Map<String, String> values = new HashMap();

   public Language(AbstractModule module) {
      this.module = module;
   }

   public static @Nullable YamlConfiguration loadLangYaml(LagFixer plugin) {
      File file = new File(plugin.getDataFolder(), "lang.yml");
      if (!file.exists() || file.getParentFile().mkdirs()) {
         plugin.saveResource("lang.yml", false);
      }

      try {
         InputStream is = plugin.getResource("lang.yml");

         YamlConfiguration var4;
         label61: {
            try {
               yaml.load(file);
               if (is != null) {
                  YamlConfiguration defaults = new YamlConfiguration();
                  defaults.load(new InputStreamReader(is, StandardCharsets.UTF_8));
                  var4 = defaults;
                  break label61;
               }
            } catch (Throwable var6) {
               if (is != null) {
                  try {
                     is.close();
                  } catch (Throwable var5) {
                     var6.addSuppressed(var5);
                  }
               }

               throw var6;
            }

            if (is != null) {
               is.close();
            }

            return null;
         }

         if (is != null) {
            is.close();
         }

         return var4;
      } catch (InvalidConfigurationException | IOException var7) {
         Exception ex = var7;
         plugin.printError(ex);
         return null;
      }
   }

   public static Component getMainValue(String key, boolean prefix, TagResolver.Single... placeholders) {
      if (!mainValues.containsKey(key)) {
         return null;
      } else {
         Component component = MiniMessage.miniMessage().deserialize((String)mainValues.get(key), placeholders);
         return (Component)(prefix ? Component.textOfChildren(new ComponentLike[]{ConfigManager.getInstance().getPrefix(), component}) : component);
      }
   }

   public void loadMessages() {
      ConfigurationSection section = yaml.getConfigurationSection("messages." + this.module.getName());
      if (section != null) {
         this.values.clear();
         section.getValues(true).forEach((key, value) -> {
            if (value instanceof String) {
               this.values.put(key, (String)value);
            }

         });
      }
   }

   public boolean hasTranslation(String key) {
      return this.values.containsKey(key);
   }

   public Component getComponent(String key, boolean prefix, TagResolver.Single... placeholders) {
      if (!this.values.containsKey(key)) {
         return null;
      } else {
         Component component = MiniMessage.miniMessage().deserialize((String)this.values.get(key), placeholders);
         return (Component)(prefix ? Component.textOfChildren(new ComponentLike[]{ConfigManager.getInstance().getPrefix(), component}) : component);
      }
   }

   public String getString(String key, boolean prefix, TagResolver.Single... placeholders) {
      Component component = this.getComponent(key, prefix, placeholders);
      return component == null ? null : getSerializer().serialize(component);
   }

   public AbstractModule getModule() {
      return this.module;
   }

   public Map<String, String> getValues() {
      return this.values;
   }

   public static YamlConfiguration getYaml() {
      return yaml;
   }

   public static LegacyComponentSerializer getSerializer() {
      return serializer;
   }

   public static Map<String, String> getMainValues() {
      return mainValues;
   }
}
